==> cwells-pingdom-0.9.3.tar.gz: cwells-pingdom-0.9.3/lib/puppet/provider/pingdom_team/team.rb <==
#
# Team provider.
#
# Author: Cliff Wells <cliff.wells@protonmail.com>
# Homepage: https://github.com/cwells/puppet-pingdom
#

begin # require PuppetX module
    require File.expand_path( # yes, this is the recommended way :P
        File.join(
            File.dirname(__FILE__), '..', '..', '..',
            'puppet_x', 'pingdom', 'client-2.1.rb'
        )
    )
    has_pingdom_api = true
rescue LoadError
    has_pingdom_api = false
end

Puppet::Type.type(:pingdom_team).provide(:team) do
    confine :true => has_pingdom_api

    def api
        @api ||= begin
            if @resource[:credentials_file]
                require 'yaml'
                # just let any exception bubble up
                creds = YAML.load_file(
                    File.expand_path @resource[:credentials_file]
                )
                account_email, user_email, password, appkey =
                    creds['account_email'], creds['user_email'], creds['password'], creds['appkey']
            else
                raise 'Missing API credentials' if [
                    @resource[:account_email],
                    @resource[:user_email],
                    @resource[:password],
                    @resource[:appkey]
                ].include? nil and @resource[:credentials_file].is_nil?
                account_email, user_email, password, appkey =
                    @resource[:account_email], @resource[:user_email], @resource[:password], @resource[:appkey]
            end
            PuppetX::Pingdom::Client.new(account_email, user_email, password, appkey, @resource[:log_level])
        end
    end

    def exists?
        @team ||= api.find_team @resource[:name]
    end

    def create
        # Dummy method. Real work is done in `flush`.
    end

    def flush
        if @resource[:ensure] == :absent
            api.delete_team @team if @team
            return
        end

        @resource.eachproperty do |prop|
            prop = prop.to_s.to_sym
            self.method("#{prop}=").call @resource[prop] if prop != :ensure
        end
        @property_hash[:name] = @resource[:name]

        if @team
            api.modify_team @team, @property_hash
        else
            api.create_team @property_hash
        end
    end

    def destroy
        @resource[:ensure] = :absent
    end

    #
    # custom getters/setters
    #
    def users
        # accepts list of ids, returns list of names
        ids = @team.fetch('users', {}).map { |i| i['id'].to_i }
        user = api.select_users(ids, search='id') if ids
        if user.respond_to? :map
            user.map { |u| u['name'] }
        else
            :absent
        end
    end

    def users=(value)
        # accepts list of names, returns list of ids
        users = api.select_users(value, search='name')
        raise 'Unknown user in list' unless users.size == value.size
        ids = users.map { |u| u['id'] }
        newvalue = ids.join(',') if ids.respond_to? :join
        @property_hash[:userids] = newvalue
    end

    #
    # utility methods
    #
    def self.accessorize
        # Provides automatic creation of missing getters/setters (accessors).
        #
        # Similar to mk_resource_methods, but doesn't clobber existing methods, thank you.
        # This allows us to have special cases explicitly defined, while still benefitting
        # from accessor auto-creation (which this class method provides).
        # Should be called at the end of every provider definition (unless you explicitly
        # define every single getter/setter).

        [ resource_type.validproperties, resource_type.parameters ].flatten.each do |prop|
            # It should be noted that this loops over all properties for all team providers.
            # This is unfortunate, but we are protected against invalid properties by the
            # `required_features` defined on each property in the type declarations.
            prop = prop.to_sym
            next if prop == :name

            if !method_defined?(prop)
                define_method(prop) do
                    @team.fetch(prop.to_s, :absent)
                end
            end

            setter = "#{prop}=".to_sym
            if !method_defined?(setter)
                define_method(setter) do |value|
                    @property_hash[prop] = value
                end
            end
        end
    end

    accessorize
end

==> cwells-pingdom-0.9.14.tar.gz: cwells-pingdom-0.9.14/lib/puppet/provider/pingdom_team/team.rb <==
#
# Team provider.
#
# Author: Cliff Wells <cliff.wells@protonmail.com>
# Homepage: https://github.com/cwells/puppet-pingdom
#
require File.expand_path(File.join(File.dirname(__FILE__), '..', 'pingdom.rb'))

Puppet::Type.type(:pingdom_team).provide(:team, :parent => Puppet::Provider::Pingdom) do

    def exists?
        @current ||= api.find_team @resource[:name]
    end

    def flush
        if @resource[:ensure] == :absent
            api.delete_team @current if @current
            return
        end

        if @current
            api.modify_team @current, @property_hash
        else
            @resource.eachproperty do |prop|
                prop = prop.to_s.to_sym
                self.method("#{prop}=").call @resource[prop] if prop != :ensure
            end
            @property_hash[:name] = @resource[:name]

            api.create_team @property_hash
        end
    end

    def destroy
        @resource[:ensure] = :absent
    end

    #
    # custom accessors
    #
    def users
        # accepts list of ids, returns list of names
        ids = @current.fetch('users', {}).map { |i| i['id'].to_i }
        user = api.select_users(ids, search='id') if ids
        if user.respond_to? :map
            user.map { |u| u['name'] }
        else
            :absent
        end
    end

    def users=(value)
        # accepts list of names, returns list of ids
        users = api.select_users(value, search='name')
        raise 'Unknown user in list' unless users.size == value.size
        ids = users.map { |u| u['id'] }
        newvalue = ids.join(',') if ids.respond_to? :join
        @property_hash[:userids] = newvalue
    end

    accessorize
end
